@@ -65,7 +65,7 @@ printWithFooter = function(gg_obj, bottom_left = NULL, bottom_right = NULL)
 #' 
 scale_x_discrete_reverse = function(values, ...)
 {
-  if ("factor" %in% class(values)) values = droplevels(values)
+  if (inherits(values, "factor")) values = droplevels(values)
   return (scale_x_discrete(limits = rev(levels(values)), ... ))
 }
 
@@ -80,7 +80,7 @@ scale_x_discrete_reverse = function(values, ...)
 #'
 scale_y_discrete_reverse = function(values, ...)
 {
-  if ("factor" %in% class(values)) values = droplevels(values)
+  if (inherits(values, "factor")) values = droplevels(values)
   return (scale_y_discrete(limits = rev(levels(values)), ... ))
 }
 
