@@ -864,7 +864,7 @@ qcMetric_EVD_Charge =  setRefClass(
       "Charge distribution per Raw file. For typtic digests, peptides of charge 2 
 (one N-terminal and one at tryptic C-terminal R or K residue) should be dominant.
 Ionization issues (voltage?), in-source fragmentation, missed cleavages and buffer irregularities can 
-cause a shift (see [Bittremieux 2017, DOI: 10.1002/mas.21544](https://onlinelibrary.wiley.com/doi/abs/10.1002/mas.21544) ).
+cause a shift (see Bittremieux 2017, DOI: 10.1002/mas.21544).
 The charge distribution should be similar across Raw files.
 Consistent charge distribution is paramount for comparable 3D-peak intensities across samples.
 
